==> nextcloud-app-calendar-1%3A2.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_AR.js <==
OC.L10N.register(
    "calendar",
    {
    "Hello," : "Hola,",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Calendar" : "Calendario",
    "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Share link" : "Compartir link",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "can edit" : "puede editar",
    "New calendar" : "Nuevo calendario",
    "Filename" : "Nombre de archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "Show week numbers" : "Mostrar número de semana",
    "Settings & import" : "Configuraciones & importar",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Unknown" : "Desconocido",
    "All day" : "Todo el día",
    "never" : "nunca",
    "after" : "después",
    "Repeat" : "Repetir",
    "Monday" : "Lunes",
    "Summary" : "Resumen",
    "More" : "Más",
    "Save" : "Guardar",
    "Update" : "Actualizar",
    "Select Date" : "Seleccionar fecha",
    "Personal" : "Personal",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Activity" : "Actividad",
    "Close" : "Cerrar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativo",
    "Cancelled" : "Cancelado",
    "Categories" : "Categoría",
    "Movie" : "Película",
    "Mail" : "Correo Electrónico",
    "Play" : "Reproducir",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A2.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/es_AR.js <==
OC.L10N.register(
    "calendar",
    {
    "Provided email-address is not valid" : "La dirección de E Mail proporcionada no es valida",
    "Successfully sent email to " : "E Mail enviado satisfactoriamente a",
    "Hello," : "Hola,",
    "Open »%s«" : "Abrir »%s«",
    "Cheers!" : "¡Saludos!",
    "Upcoming events" : "Próximos eventos",
    "Calendar" : "Calendario",
    "A Calendar app for Nextcloud" : "Una aplicación de calendario para Nextcloud",
    "Previous day" : "Día previo",
    "Previous week" : "Semana previa",
    "Previous month" : "Mes previo",
    "Next day" : "Proximo día",
    "Next week" : "Proxima semana",
    "Next month" : "Proximo mes",
    "+ New event" : "+ Nuevo evento",
    "Today" : "Hoy",
    "Day" : "Día",
    "Week" : "Semana",
    "Month" : "Mes",
    "List" : "Lista",
    "Edit name" : "Editar nombre",
    "Edit color" : "Editar color",
    "Download" : "Descargar",
    "Delete" : "Borrar",
    "Share link" : "Compartir link",
    "Copy public link" : "Copiar link publico",
    "Copied link" : "Link copiado",
    "Copied code" : "Código copiado",
    "Share with users or groups" : "Compartir con usuarios o grupos",
    "No users or groups" : "No hay usuarios ni grupos.",
    "can edit" : "puede editar",
    "New calendar" : "Nuevo calendario",
    "New calendar with task list" : "Nuevo calendario con listado de tareas",
    "Filename" : "Nombre de archivo",
    "Cancel" : "Cancelar",
    "Automatic" : "Automático",
    "Actions" : "Acciones",
    "Show week numbers" : "Mostrar número de semana",
    "Settings & import" : "Configuraciones & importar",
    "Notification" : "Notificación",
    "Email" : "Correo electrónico",
    "Unknown" : "Desconocido",
    "All day" : "Todo el día",
    "never" : "nunca",
    "after" : "después",
    "Repeat" : "Repetir",
    "Monday" : "Lunes",
    "Summary" : "Resumen",
    "More" : "Más",
    "Save" : "Guardar",
    "Update" : "Actualizar",
    "Personal" : "Personal",
    "Details" : "Detalles",
    "Attendees" : "Asistentes",
    "Reminders" : "Recordatorios",
    "Close" : "Cerrar",
    "Anniversary" : "Aniversario",
    "Week {number} of {year}" : "Semana {number} de {year}",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "today" : "hoy",
    "When shared show full event" : "Al compartir, mostrar el evento completo",
    "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
    "When shared hide this event" : "Al compartir, ocultar este evento ",
    "Location" : "Ubicación",
    "Description" : "Descripción",
    "Status" : "Estatus",
    "Confirmed" : "Confirmado",
    "Tentative" : "Tentativo",
    "Categories" : "Categoría",
    "Movie" : "Película",
    "Mail" : "Correo Electrónico",
    "Play" : "Reproducir",
    "Global" : "Global"
},
"nplurals=2; plural=(n != 1);");
